@@ -13,7 +13,7 @@ class ShowSchemasPlugin(BaseRelPlugin):
     functionality.
     The SQL is:
 
-        SHOW SCHEMAS
+        SHOW SCHEMAS (FROM ... LIKE ...)
 
     The result is also a table, although it is created on the fly.
     """
@@ -23,7 +23,14 @@ class ShowSchemasPlugin(BaseRelPlugin):
     def convert(
         self, sql: "org.apache.calcite.sql.SqlNode", context: "dask_sql.Context"
     ) -> DataContainer:
-        df = pd.DataFrame({"Schema": [context.schema_name]})
+        # "information_schema" is a schema which is found in every presto database
+        schema = context.schema_name
+        df = pd.DataFrame({"Schema": [schema, "information_schema"]})
+
+        # We currently do not use the passed additional parameter FROM.
+        like = str(sql.like).strip("'")
+        if like and like != "None":
+            df = df[df.Schema == like]
 
         cc = ColumnContainer(df.columns)
         dc = DataContainer(dd.from_pandas(df, npartitions=1), cc)
